@@ -28,7 +28,7 @@ class Sources(BaseModel):
 
 class Environment(BaseModel):
     sources: Sources
-    variables: dict[str, str] | None
+    variables: dict[str, str] = {}
 
 
 class Config(BaseModel):
