@@ -12,13 +12,10 @@ def push(env: Environment, pkg: Package):
         pg_client.connect(env.sources.postgres) as pg_conn,
         s3_client.connect(env.sources.s3) as s3_conn,
     ):
+        print("[source:postgres] pushing artefacts...")
         for artefact in pg_artefacts:
-            print(f"[source:postgres] pushing {artefact.table} artefact")
             pg_client.insert(pg_conn, artefact.table, artefact.data)
 
+        print("[source:s3] pushing artefacts...")
         for artefact in s3_artefacts:
-            print(f"[source:s3] pushing {artefact} artefact")
             s3_client.upload(s3_conn, artefact.bucket, artefact.key, artefact.tmp_path)
-
-        pg_conn.commit()
-        # s3_conn.commit()
