@@ -1,4 +1,3 @@
-from contextlib import contextmanager
 from typing import TYPE_CHECKING
 
 import psycopg2.extensions as ext
@@ -26,16 +25,6 @@ def connect(config: PostgresConfig):
     )
 
 
-@contextmanager
-def disabled_contraints(conn: "connection"):
-    with conn.cursor() as cursor:
-        cursor.execute("set session_replication_role = 'origin'")
-
-        yield
-
-        cursor.execute("set session_replication_role = 'replica'")
-
-
 def insert(conn: "connection", table: str, row: dict):
     with conn.cursor() as cursor:
         cursor.execute(
