@@ -65,13 +65,3 @@ def pull_node(env: Environment, node: PostgresNode, variables: dict):
             print(f"[source:postgres] pulling {artefact} artefact")
 
             yield artefact
-
-
-def push_artefacts(env: Environment, artefacts: list[PostgresArtefact]):
-    with client.connect(env.sources.postgres) as conn:
-        with client.disabled_contraints(conn):
-            for artefact in artefacts:
-                print(f"importing {artefact.table}")
-                client.insert(conn, artefact.table, artefact.data)
-
-        conn.commit()
