@@ -3,14 +3,16 @@ from contextlib import contextmanager
 
 import boto3
 
+from datapac.config import S3Config
+
 
 @contextmanager
-def connect(endpoint_url: str | None, access_key_id: str, secret_access_key: str):
+def connect(config: S3Config):
     yield boto3.client(
         "s3",
-        endpoint_url=endpoint_url,
-        aws_access_key_id=access_key_id,
-        aws_secret_access_key=secret_access_key,
+        endpoint_url=config.endpoint_url,
+        aws_access_key_id=config.aws_access_key_id,
+        aws_secret_access_key=config.aws_secret_access_key,
     )
 
 
